@@ -51,5 +51,5 @@ def _convert(value, setting):
         else:
             return value
 
-def read_conf(file):
+def read_conf(file) -> MyConfig:
     return MyConfig(file)
