@@ -9,7 +9,7 @@ class Logger(BaseModel):
     log_path: str = "/var/log"
 
     def initial(self, filename):
-        filename = '{}/{}'.format(config.log_path, filename)
+        filename = '{}/{}'.format(self.log_path, filename)
         logger.add(filename, rotation=self.rotation, retention=self.retention, compression=self.compression, level=self.level)
 
         return logger
