@@ -2,12 +2,14 @@ from typing import Any
 from pydantic import BaseModel
 from redis import StrictRedis
 
+
 class Redis(BaseModel):
     host: str
     port: int = 6379
     db: int = 0
 
     redis: Any = None
+    cache: Any = None
 
     def connect(self) -> StrictRedis:
         return StrictRedis(host=self.host, port=self.port, db=self.db, decode_responses=True)
@@ -48,3 +50,10 @@ class Redis(BaseModel):
         except Exception:
             return self.connect().rpop(queue)
 
+    def cache_it(self, *, limit=100000, expire=3600, hashkeys=True, namespace="default"):
+        if self.cache==None:
+            from redis_cache import SimpleCache,cache_it
+            my_cache = SimpleCache(limit=limit, expire=expire, hashkeys=hashkeys, host=self.host, port=self.port, db=self.db, namespace=namespace)
+            self.cache = cache_it(cache=my_cache)
+        return self.cache
+
